@@ -10,21 +10,25 @@
 #include <QCommandLineParser>
 #include <QIcon>
 #include <QImage>
+#include <QAbstractListModel>
 
 #include <KAboutData>
 #include <KCrash>
 #include <KLocalizedContext>
 #include <KLocalizedString>
-#include <KSaneOption>
+#include <Option>
 
 #include "DevicesModel.h"
 #include "DocumentModel.h"
 #include "FormatModel.h"
 #include "FilteredOptionsModel.h"
+#include "OCRLanguageModel.h"
 #include "InProgressPainter.h"
 #include "Skanpage.h"
 #include "SkanpageUtils.h"
 #include "skanpage_version.h"
+#include "skanpage_config.h"
+#include "skanpage_state.h"
 
 int main(int argc, char *argv[])
 {
@@ -37,9 +41,12 @@ int main(int argc, char *argv[])
     qmlRegisterUncreatableType<DocumentModel>("org.kde.skanpage", 1, 0, "DocumentModel", QStringLiteral("Document model class uncreateable"));
     qmlRegisterUncreatableType<DevicesModel>("org.kde.skanpage", 1, 0, "DevicesModel", QStringLiteral("Device model class uncreateable"));
     qmlRegisterUncreatableType<FormatModel>("org.kde.skanpage", 1, 0, "FormatModel", QStringLiteral("Format model class uncreateable"));
-    qmlRegisterUncreatableType<FilteredOptionsModel>("org.kde.skanpage", 1, 0, "FilteredOptionsModel", QStringLiteral("Filtered options model class uncreateable"));;
-    qmlRegisterUncreatableType<KSaneOption>("org.kde.skanpage", 1, 0, "KSaneOption", QStringLiteral("KSaneOption class uncreateable"));
+    qmlRegisterUncreatableType<FilteredOptionsModel>("org.kde.skanpage", 1, 0, "FilteredOptionsModel", QStringLiteral("Filtered options model class uncreateable"));
+    qmlRegisterUncreatableType<OCRLanguageModel>("org.kde.skanpage", 1, 0, "OCRLanguageModel", QStringLiteral("OCR language model class uncreateable"));;
+    qmlRegisterUncreatableType<KSaneCore::Option>("org.kde.skanpage", 1, 0, "KSaneOption", QStringLiteral("KSaneOption class uncreateable"));
     qmlRegisterUncreatableType<Skanpage>("org.kde.skanpage", 1, 0, "Skanpage", QStringLiteral("Skanpage application class uncreateable"));
+    qmlRegisterUncreatableType<SkanpageConfiguration>("org.kde.skanpage", 1, 0, "Configuration", QStringLiteral("Confguration class uncreatable"));
+    qmlRegisterUncreatableType<SkanpageState>("org.kde.skanpage", 1, 0, "StateConfiguration", QStringLiteral("State class uncreatable"));
     qmlRegisterUncreatableMetaObject(SkanpageUtils::staticMetaObject, "org.kde.skanpage", 1, 0, "SkanpageUtils", QStringLiteral("Error: only enums"));
     qmlRegisterType<InProgressPainter>("org.kde.skanpage", 1, 0, "InProgressPainter");
     qRegisterMetaType<SkanpageUtils::MessageLevel>();
@@ -53,9 +60,9 @@ int main(int argc, char *argv[])
     KAboutData aboutData(QLatin1String("skanpage"),
                          i18n("Skanpage"),
                          QLatin1String(SKANPAGE_VERSION_STRING),
-                         i18n("Page-scanning application by KDE based on libksane."),
+                         i18n("Multi-page scanning application by KDE."),
                          KAboutLicense::GPL,
-                         i18n("© 2015-2021 Kåre Särs, Alexander Stippich")
+                         i18n("© 2015-2022 Kåre Särs, Alexander Stippich")
     );
 
     aboutData.addAuthor(QStringLiteral("Kåre Särs"), i18n("developer"), QLatin1String("kare.sars@iki.fi"));
